@@ -1333,7 +1333,7 @@ def set_common_pglog():
    if valid_command(sm): SETPGLOG("EMLSEND", f"{sm} -t")   # send email command
    SETPGLOG("DBGLEVEL", '')                             # debug level
    SETPGLOG("DBGPATH", PGLOG['DSSDBHM']+"/log")         # path to debug log file
-   SETPGLOG("OBJCTBKT", "rda-data")                     # default Bucket on Object Store
+   SETPGLOG("OBJCTBKT", "gdex-data")                     # default Bucket on Object Store
    SETPGLOG("BACKUPEP", "gdex-quasar")                   # default Globus Endpoint on Quasar
    SETPGLOG("DRDATAEP", "gdex-quasar-drdata")            # DRDATA Globus Endpoint on Quasar
    SETPGLOG("DBGFILE", "pgdss.dbg")                     # debug file name
@@ -1349,19 +1349,20 @@ def set_common_pglog():
    SETPGLOG("DSSWEB",  PGLOG['LOCDATA']+"/web")
    SETPGLOG("DSWHOME", PGLOG['DSSWEB']+"/datasets")     # datast web root path
    PGLOG['HOMEROOTS'] = "{}|{}".format(PGLOG['DSSHOME'], PGLOG['DSWHOME'])
-   SETPGLOG("DSSDATA", "/glade/campaign/collections/gdex")                     # dss data root path
+   SETPGLOG("DSSDATA", "/glade/campaign/collections/gdex")  # dss data root path
    SETPGLOG("DSDHOME", PGLOG['DSSDATA']+"/data")        # dataset data root path
    SETPGLOG("DECSHOME", PGLOG['DSSDATA']+"/decsdata")   # dataset decsdata root path
    SETPGLOG("DSHHOME", PGLOG['DECSHOME']+"/helpfiles")  # dataset help root path
-   SETPGLOG("UPDTWKP", PGLOG['DSSDATA']+"/work")        # dsupdt work root path
-   SETPGLOG("TRANSFER", PGLOG['DSSDATA']+"/transfer")   # dss transfer partition
+   SETPGLOG("GDEXWORK", "/lustre/desc1/gdex/work")      # gdex work path
+   SETPGLOG("UPDTWKP", PGLOG['GDEXWORK'])               # dsupdt work root path
+   SETPGLOG("TRANSFER", "/lustre/desc1/gdex/transfer")  # gdex transfer path
    SETPGLOG("RQSTHOME", PGLOG['TRANSFER']+"/dsrqst")    # dsrqst home
-   SETPGLOG("DSAHOME",  "")                    # dataset data alternate root path
+   SETPGLOG("DSAHOME",  "")                   # dataset data alternate root path
    SETPGLOG("RQSTALTH", "")                   # alternate dsrqst path
    SETPGLOG("GPFSHOST", "")                   # empty if writable to glade
-   SETPGLOG("PSQLHOST", "rda-db.ucar.edu")                   # host name for postgresql server
-   SETPGLOG("SLMHOSTS", "cheyenne:casper")                   # host names for SLURM server
-   SETPGLOG("PBSHOSTS", "cheyenne:casper")                   # host names for PBS server
+   SETPGLOG("PSQLHOST", "rda-db.ucar.edu")    # host name for postgresql server
+   SETPGLOG("SLMHOSTS", "cheyenne:casper")    # host names for SLURM server
+   SETPGLOG("PBSHOSTS", "cron:casper")        # host names for PBS server
    SETPGLOG("CHKHOSTS", "")                   # host names for dscheck daemon
    SETPGLOG("PVIEWHOST", "pgdb02.k8s.ucar.edu")             # host name for view only postgresql server
    SETPGLOG("PMISCHOST", "pgdb03.k8s.ucar.edu")             # host name for misc postgresql server
@@ -1373,12 +1374,12 @@ def set_common_pglog():
    os.environ['history'] = '0'
 
    # set tmp dir
-   SETPGLOG("TMPPATH", "/glade/campaign/collections/gdex/work/ptmp")
+   SETPGLOG("TMPPATH", PGLOG['GDEXWORK'] + "/ptmp")
    if not PGLOG['TMPPATH']: PGLOG['TMPPATH'] = "/data/ptmp"
 
    SETPGLOG("TMPDIR", '')
    if not PGLOG['TMPDIR']:
-      PGLOG['TMPDIR'] = "/glade/campaign/collections/gdex/scratch/" + PGLOG['CURUID']
+      PGLOG['TMPDIR'] = "/lustre/desc1/gdex/scratch/" + PGLOG['CURUID']
       os.environ['TMPDIR'] = PGLOG['TMPDIR']
 
    # empty diretory for HOST-sync
